@@ -9,7 +9,7 @@ test_that("lets.distmat works fine, asdist = TRUE", {
   
   
   distPAM <- lets.distmat(PAM)   
-  expect_true(class(distPAM) == "dist")
+  expect_true(class(distPAM)[1] == "dist")
   expect_true(all(dim(as.matrix(distPAM)) == dimPAM))
     
 })
@@ -19,7 +19,7 @@ test_that("lets.distmat works fine, asdist = FALSE", {
   
   
   distPAM <- lets.distmat(PAM, asdist = FALSE)   
-  expect_true(class(distPAM) == "matrix")
+  expect_true(class(distPAM)[1] == "matrix")
   expect_true(all(dim(distPAM) == dimPAM))
   
 })
@@ -29,7 +29,7 @@ test_that("lets.distmat works fine, miles = TRUE", {
   
   
   distPAM <- lets.distmat(PAM, miles = TRUE)   
-  expect_true(class(distPAM) == "dist")
+  expect_true(class(distPAM)[1] == "dist")
   expect_true(all(dim(as.matrix(distPAM)) == dimPAM))
   
 })
@@ -38,7 +38,7 @@ test_that("lets.distmat works fine, xy as matrix ", {
   
   
   distPAM <- lets.distmat(coords, miles = TRUE)   
-  expect_true(class(distPAM) == "dist")
+  expect_true(class(distPAM)[1] == "dist")
   expect_true(all(dim(as.matrix(distPAM)) == nrow(coords)))
   
 })
