@@ -10,7 +10,7 @@ test_that("lets.rangesize works fine, geographic", {
   resu_test <- lets.rangesize(x = Phyllomedusa,
                               coordinates = "geographic")
   
-  expect_equal(class(resu_test), "matrix")
+  expect_equal(class(resu_test)[1], "matrix")
   expect_true(ncol(resu_test) == 1)
   expect_true(!any(is.na(resu_test)))
 })
@@ -22,7 +22,7 @@ test_that("lets.rangesize works fine, planar", {
   resu_test <- lets.rangesize(x = Phyllomedusa,
                               coordinates = "planar")
   
-  expect_equal(class(resu_test), "matrix")
+  expect_equal(class(resu_test)[1], "matrix")
   expect_true(ncol(resu_test) == 1)
   expect_true(!any(is.na(resu_test)))
 })
@@ -33,7 +33,7 @@ test_that("lets.rangesize works fine, squaremeter", {
   resu_test <- lets.rangesize(x = PAM,
                               units = "squaremeter")
   
-  expect_equal(class(resu_test), "matrix")
+  expect_equal(class(resu_test)[1], "matrix")
   expect_true(ncol(resu_test) == 1)
   expect_true(!any(is.na(resu_test)))
 })
@@ -45,7 +45,7 @@ test_that("lets.rangesize works fine, squaremeter", {
   resu_test <- lets.rangesize(x = PAM,
                               units = "cell")
   
-  expect_equal(class(resu_test), "matrix")
+  expect_equal(class(resu_test)[1], "matrix")
   expect_true(ncol(resu_test) == 1)
   expect_true(!any(is.na(resu_test)))
 })
@@ -56,7 +56,7 @@ test_that("lets.rangesize works fine, squaremeter global", {
   resu_test <- lets.rangesize(x = PAM2,
                               units = "squaremeter")
   
-  expect_equal(class(resu_test), "matrix")
+  expect_equal(class(resu_test)[1], "matrix")
   expect_true(ncol(resu_test) == 1)
   expect_true(!any(is.na(resu_test)))
 })
