@@ -7,10 +7,10 @@ test_that("lets.subsetPAM works fine, remove.cells = TRUE", {
   
   resu_test <- lets.subsetPAM(PAM, PAM[[3]][1:20])
   
-  expect_equal(class(resu_test), "PresenceAbsence")
-  expect_equal(class(resu_test[[1]]), "matrix")
+  expect_equal(class(resu_test)[1], "PresenceAbsence")
+  expect_equal(class(resu_test[[1]])[1], "matrix")
   expect_true(inherits(resu_test[[2]], "RasterLayer"))
-  expect_equal(class(resu_test[[3]]), "character")
+  expect_equal(class(resu_test[[3]])[1], "character")
   
   response <- summary(resu_test)
   expect_true(response$Cellswithoutanypresence == 0)
@@ -23,10 +23,10 @@ test_that("lets.subsetPAM works fine, remove.cells = FALSE", {
   resu_test <- lets.subsetPAM(PAM, PAM[[3]][1:20],
                               remove.cells = FALSE)
   
-  expect_equal(class(resu_test), "PresenceAbsence")
-  expect_equal(class(resu_test[[1]]), "matrix")
+  expect_equal(class(resu_test)[1], "PresenceAbsence")
+  expect_equal(class(resu_test[[1]])[1], "matrix")
   expect_true(inherits(resu_test[[2]], "RasterLayer"))
-  expect_equal(class(resu_test[[3]]), "character")
+  expect_equal(class(resu_test[[3]])[1], "character")
   
   response <- summary(resu_test)
   expect_true(response$Cellswithoutanypresence > 0)
